---
title: <span class="badge object-type-scalar"></span> MebibitsPerSecond
---
# <span class="badge object-type-scalar"></span> MebibitsPerSecond

Data rate: mebibits/sec

## Definition

```python
# Data rate: mebibits/sec
MebibitsPerSecond: typing.Literal["Mibits"] = "Mibits"
```
